@@ -161,7 +161,7 @@ groupApply <- function(tbl, groupVariable, fun, ..., batchSize = 100000, progres
     env$groupData <- groups[[length(groups)]]
     env$groupValue <- groups[[length(groups)]][1, groupVariable]
   }
-  batchApply(tbl = tbl %>% arrange(groupVariable),
+  batchApply(tbl = tbl %>% arrange(.data[[groupVariable]]),
              fun = wrapper,
              userFun = fun,
              env = env,
